1.3.3
=====

Bump to richxerox 1.0.1 for declared dependency on pyobjc.

Run CI tests on macOS and Windows.

1.3.2
=====

Refresh packaging.

Update dependency declaration on richxerox.

Update dependency on pyperclip and fix usage.

1.3.1
=====

Refresh packaging.

1.3
===

Add support for copy/paste text on Linux via pyperclip.

1.2
===

Added test suite and automated deployments for tagged
commits.

1.1
===

Move hosting to github.

1.0
===

Initial implementation with text and HTML support on Windows
and Mac OS X and image paste support on Windows.
